#! /usr/bin/perl -w
#-IEcoStations-2.1
# Laurent Guinard - Académie de Reims
# copie du fichier /usr/share/eole/controlevnc/machines.db pour menu déroulant de choix

$REP_ECOSTATION="/var/www/html/outils/ecoStations";
my $version=`grep EOLE_VERSION /etc/eole/release | tr -d "'" | cut -d '=' -f2`;
if( $version == "2.5" || $version == "2.6" ) {
	`/usr/share/eole/controlevnc/manage_stations.py --list-all > /usr/share/eole/controlevnc/machines.db`;
	`sed -i 's#;#\\n#g' /usr/share/eole/controlevnc/machines.db`;
	`sed -i 's#,#;#g' /usr/share/eole/controlevnc/machines.db`;
	`cp /usr/share/eole/controlevnc/machines.db $REP_ECOSTATION/config/copie_machines.db`;
} else {
	`LANG=fr_FR.UTF-8 salt-run mine.get '*' all_grains --out=json > $REP_ECOSTATION/config/copie_machines.db`;
}

`chown root:www-data $REP_ECOSTATION/config/copie_machines.db`;
`chmod 770 $REP_ECOSTATION/config/copie_machines.db`;
